@@ -1,7 +1,7 @@
 package Bencher::Backend;
 
-our $DATE = '2016-03-22'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2016-03-24'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Data::Dmp;
+use List::MoreUtils qw(all);
 use List::Util qw(first);
 
 our %SPEC;
@@ -138,7 +139,11 @@ sub _get_scenario {
     } elsif (defined $pargs->{scenario_module}) {
         my $m = "Bencher::Scenario::$pargs->{scenario_module}"; $m =~ s!/!::!g;
         my $mp = $m; $mp =~ s!::!/!g; $mp .= ".pm";
-        require $mp;
+        {
+            local @INC = @INC;
+            unshift @INC, $_ for @{ $pargs->{include_path} // [] };
+            require $mp;
+        }
         no strict 'refs';
         $scenario = ${"$m\::scenario"};
     } else {
@@ -290,10 +295,39 @@ sub _parse_scenario {
     if ($unparsed->{datasets}) {
         $parsed->{datasets} = [];
         my $i = -1;
-        for my $ds0 (@{ $unparsed->{datasets} }) {
+        my $dss0 = $unparsed->{datasets};
+
+        my $td_args;
+        my @uniq_args;
+
+        for my $ds0 (@$dss0) {
             $i++;
             my $ds = { %$ds0, seq=>$i };
             $ds->{include_by_default} //= 1;
+
+            # try to come up with a nicer name for the dataset (not necessarily
+            # unique): extract from argument values
+            unless (defined($ds->{name})) {
+                unless ($td_args) {
+                    if (all {$_->{args}} @$dss0) {
+                        require TableData::Object::aohos;
+                        $td_args = TableData::Object::aohos->new(
+                            [map {$_->{args}} @$dss0]);
+                        @uniq_args = $td_args->uniq_col_names;
+                    } else {
+                        $td_args = -1;
+                    }
+                }
+                if (@uniq_args > 1) {
+                    $ds->{name} = dmp(
+                        { map {$_ => $ds->{args}{$_}} @uniq_args });
+                } elsif (@uniq_args) {
+                    $ds->{name} = $ds->{args}{$uniq_args[0]};
+                    $ds->{name} = dmp($ds->{name}) if ref($ds->{name});
+                }
+            }
+
+
             push @{ $parsed->{datasets} }, $ds;
         } # for each dataset
 
@@ -1204,7 +1238,6 @@ $SPEC{bencher} = {
         # XXX note is only relevant when action=bench
         # XXX sort is only relevant when action=bench and format=text
         # XXX include_perls & exclude_perls are only relevant when multiperl=1
-        # XXX include_path only relevant when multimodver=1
     },
     args => {
         scenario_file => {
@@ -1633,7 +1666,7 @@ _
             schema => ['array*', of=>['str*']],
             description => <<'_',
 
-Only relevant when in multimodver mode.
+Used when searching for scenario module, or when in multimodver mode.
 
 _
             cmdline_aliases => {I=>{}},
@@ -1732,6 +1765,8 @@ sub bencher {
 
     if ($action eq 'list-scenario-modules') {
         require PERLANCAR::Module::List;
+        local @INC = @INC;
+        unshift @INC, $_ for @{ $args{include_path} // [] };
         my $mods = PERLANCAR::Module::List::list_modules(
             'Bencher::Scenario::', {list_modules=>1, recurse=>1});
         $envres =
@@ -2313,7 +2348,7 @@ Bencher::Backend - Backend for Bencher
 
 =head1 VERSION
 
-This document describes version 0.42 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-22.
+This document describes version 0.43 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-24.
 
 =head1 FUNCTIONS
 
@@ -2448,7 +2483,7 @@ Only include participants whose seq/name matches this.
 
 Additional module search paths.
 
-Only relevant when in multimodver mode.
+Used when searching for scenario module, or when in multimodver mode.
 
 =item * B<include_perls> => I<array[str]>
 
